CREATE TABLE `spree_users` (
  `id` int NOT NULL AUTO_INCREMENT,
  `encrypted_password` varchar(128) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{64,96}"',
  `password_salt` varchar(128) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{64,96}"',
  `email` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{14,20}"',
  `remember_token` varchar(255) DEFAULT NULL,
  `persistence_token` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{14,40}"',
  `reset_password_token` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{14,40}"',
  `perishable_token` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{14,40}"',
  `sign_in_count` int NOT NULL DEFAULT '0',
  `failed_attempts` int NOT NULL DEFAULT '0',
  `last_request_at` datetime DEFAULT CURRENT_TIMESTAMP,
  `current_sign_in_at` datetime DEFAULT CURRENT_TIMESTAMP,
  `last_sign_in_at` datetime DEFAULT CURRENT_TIMESTAMP,
  `current_sign_in_ip` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{15,15}"',
  `last_sign_in_ip` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{15,15}"',
  `login` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{10,20}"',
  `ship_address_id` int DEFAULT '0',
  `bill_address_id` int DEFAULT '124',
  `created_at` datetime(6) NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `updated_at` datetime(6) NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `spree_api_key` varchar(48) DEFAULT NULL,
  `authentication_token` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{14,40}"',
  `unlock_token` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{14,40}"',
  `locked_at` datetime DEFAULT CURRENT_TIMESTAMP,
  `remember_created_at` datetime DEFAULT CURRENT_TIMESTAMP,
  `reset_password_sent_at` datetime DEFAULT CURRENT_TIMESTAMP,
  `deleted_at` datetime DEFAULT NULL,
  `confirmation_token` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{14,40}"',
  `confirmed_at` datetime DEFAULT NULL,
  `confirmation_sent_at` datetime DEFAULT NULL,
  `unconfirmed_email` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `email_idx_unique` (`email`),
  UNIQUE KEY `index_spree_users_on_reset_password_token_solidus_auth_devise` (`reset_password_token`),
  KEY `index_spree_users_on_spree_api_key` (`spree_api_key`),
  KEY `index_spree_users_on_deleted_at` (`deleted_at`)
) ENGINE=InnoDB AUTO_INCREMENT=10000000 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;


CREATE TABLE `spree_products` (
  `id` int NOT NULL AUTO_INCREMENT,
  `name` varchar(255) NOT NULL COMMENT 'REGEX "[A-Z][a-z]{10,200}"',
  `description` text COMMENT 'REGEX "[A-Z][a-z]{100,256}"',
  `available_on` datetime DEFAULT CURRENT_TIMESTAMP,
  `deleted_at` datetime DEFAULT CURRENT_TIMESTAMP,
  `slug` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{10,200}"',
  `meta_description` text COMMENT 'REGEX "[A-Z][a-z]{100,200}"',
  `meta_keywords` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{40,60}"',
  `tax_category_id` int DEFAULT '14',
  `shipping_category_id` int DEFAULT '200',
  `created_at` datetime(6) DEFAULT CURRENT_TIMESTAMP,
  `updated_at` datetime(6) DEFAULT CURRENT_TIMESTAMP,
  `promotionable` tinyint(1) DEFAULT '1',
  `meta_title` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{100,200}"',
  `discontinue_on` datetime DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `index_spree_products_on_slug` (`slug`),
  KEY `index_spree_products_on_available_on` (`available_on`),
  KEY `index_spree_products_on_deleted_at` (`deleted_at`),
  KEY `index_spree_products_on_name` (`name`)
) ENGINE=InnoDB AUTO_INCREMENT=2000000 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;

CREATE TABLE `spree_product_properties` (
  `id` int NOT NULL AUTO_INCREMENT,
  `value` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{100,220}"',
  `product_id` int DEFAULT NULL COMMENT 'group 1',
  `property_id` int DEFAULT NULL COMMENT 'group 2',
  `created_at` datetime(6) DEFAULT CURRENT_TIMESTAMP,
  `updated_at` datetime(6) DEFAULT CURRENT_TIMESTAMP,
  `position` int DEFAULT '0',
  PRIMARY KEY (`id`),
  KEY `index_spree_product_properties_on_position` (`position`),
  KEY `index_product_properties_on_product_id` (`product_id`),
  KEY `index_spree_product_properties_on_property_id` (`property_id`)
) ENGINE=InnoDB AUTO_INCREMENT=2000000 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;

CREATE TABLE `spree_variants` (
  `id` int NOT NULL AUTO_INCREMENT,
  `sku` varchar(255) NOT NULL COMMENT 'REGEX "[A-Z][a-z]{100,220}"',
  `weight` decimal(8,2) DEFAULT '14.0',
  `height` decimal(8,2) DEFAULT '14.0',
  `width` decimal(8,2) DEFAULT '14.0',
  `depth` decimal(8,2) DEFAULT '14.0',
  `deleted_at` datetime DEFAULT NULL,
  `is_master` tinyint(1) DEFAULT '1',
  `product_id` int DEFAULT NULL COMMENT 'group 2',
  `cost_price` decimal(10,2) DEFAULT NULL,
  `position` int DEFAULT NULL,
  `cost_currency` varchar(255) DEFAULT NULL,
  `track_inventory` tinyint(1) DEFAULT '1',
  `tax_category_id` int DEFAULT '214',
  `updated_at` datetime(6) DEFAULT CURRENT_TIMESTAMP,
  `created_at` datetime(6) DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  KEY `index_spree_variants_on_position` (`position`),
  KEY `index_spree_variants_on_product_id` (`product_id`),
  KEY `index_spree_variants_on_sku` (`sku`),
  KEY `index_spree_variants_on_tax_category_id` (`tax_category_id`),
  KEY `index_spree_variants_on_track_inventory` (`track_inventory`)
) ENGINE=InnoDB AUTO_INCREMENT=4000000 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;

CREATE TABLE `spree_prices` (
  `id` int NOT NULL AUTO_INCREMENT,
  `variant_id` int NOT NULL COMMENT 'group 1',
  `amount` decimal(10,2) NOT NULL,
  `currency` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{2,3}"',
  `deleted_at` datetime DEFAULT NULL,
  `created_at` datetime(6) DEFAULT CURRENT_TIMESTAMP,
  `updated_at` datetime(6) DEFAULT CURRENT_TIMESTAMP,
  `country_iso` varchar(2) DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  KEY `index_spree_prices_on_country_iso` (`country_iso`),
  KEY `index_spree_prices_on_variant_id_and_currency` (`variant_id`,`currency`)
) ENGINE=InnoDB AUTO_INCREMENT=4000000 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;

CREATE TABLE `spree_orders` (
  `id` int NOT NULL AUTO_INCREMENT,
  `number` varchar(32) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{10,30}"',
  `item_total` decimal(10,2) NOT NULL DEFAULT '27.1',
  `total` decimal(10,2) NOT NULL DEFAULT '28.19',
  `state` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{10,20}"',
  `adjustment_total` decimal(10,2) NOT NULL DEFAULT '29.99',
  `user_id` int DEFAULT NULL COMMENT 'UNIFORM 0 10000000',
  `completed_at` datetime DEFAULT CURRENT_TIMESTAMP,
  `bill_address_id` int DEFAULT '111',
  `ship_address_id` int DEFAULT '121',
  `payment_total` decimal(10,2) DEFAULT '29.99',
  `shipment_state` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{2,8}"',
  `payment_state` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{2,8}"',
  `email` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{14,21}"',
  `special_instructions` text,
  `created_at` datetime(6) DEFAULT CURRENT_TIMESTAMP,
  `updated_at` datetime(6) DEFAULT CURRENT_TIMESTAMP,
  `currency` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{10,200}"',
  `last_ip_address` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{10,200}"',
  `created_by_id` int DEFAULT NULL,
  `shipment_total` decimal(10,2) NOT NULL DEFAULT '29.99',
  `additional_tax_total` decimal(10,2) DEFAULT '0.00',
  `promo_total` decimal(10,2) DEFAULT '0.00',
  `channel` varchar(255) DEFAULT 'spree',
  `included_tax_total` decimal(10,2) NOT NULL DEFAULT '0.00',
  `item_count` int DEFAULT '0',
  `approver_id` int DEFAULT NULL,
  `approved_at` datetime DEFAULT NULL,
  `confirmation_delivered` tinyint(1) DEFAULT '0',
  `guest_token` varchar(255) DEFAULT NULL,
  `canceled_at` datetime DEFAULT NULL,
  `canceler_id` int DEFAULT NULL,
  `store_id` int DEFAULT NULL COMMENT 'group 1000',
  `approver_name` varchar(255) DEFAULT NULL,
  `frontend_viewable` tinyint(1) NOT NULL DEFAULT '1',
  PRIMARY KEY (`id`),
  KEY `index_spree_orders_on_approver_id` (`approver_id`),
  KEY `index_spree_orders_on_bill_address_id` (`bill_address_id`),
  KEY `index_spree_orders_on_completed_at` (`completed_at`),
  KEY `index_spree_orders_on_created_by_id` (`created_by_id`),
  KEY `index_spree_orders_on_guest_token` (`guest_token`),
  KEY `index_spree_orders_on_number` (`number`),
  KEY `index_spree_orders_on_ship_address_id` (`ship_address_id`),
  KEY `index_spree_orders_on_user_id_and_created_by_id` (`user_id`,`created_by_id`),
  KEY `index_spree_orders_on_user_id` (`user_id`)
) ENGINE=InnoDB AUTO_INCREMENT=10000000 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;

CREATE TABLE `spree_assets` (
  `id` int NOT NULL AUTO_INCREMENT,
  `viewable_type` varchar(255) DEFAULT 'Spree::Variant',
  `viewable_id` int DEFAULT NULL COMMENT 'group 1',
  `attachment_width` int DEFAULT '4',
  `attachment_height` int DEFAULT '5',
  `attachment_file_size` int DEFAULT '6',
  `position` int DEFAULT '7',
  `attachment_content_type` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{10,50}"',
  `attachment_file_name` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{10,50}"',
  `type` varchar(75) DEFAULT 'Spree::Image',
  `attachment_updated_at` datetime DEFAULT CURRENT_TIMESTAMP,
  `alt` text,
  `created_at` datetime(6) DEFAULT CURRENT_TIMESTAMP,
  `updated_at` datetime(6) DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  KEY `index_assets_on_viewable_id` (`viewable_id`),
  KEY `index_assets_on_viewable_type_and_type` (`viewable_type`,`type`)
) ENGINE=InnoDB AUTO_INCREMENT=4000000 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;

CREATE TABLE `spree_option_values` (
  `id` int NOT NULL AUTO_INCREMENT,
  `position` int DEFAULT '7',
  `name` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{3,20}"',
  `presentation` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{3,8}"',
  `option_type_id` int DEFAULT '21',
  `created_at` datetime(6) DEFAULT CURRENT_TIMESTAMP,
  `updated_at` datetime(6) DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  KEY `index_spree_option_values_on_option_type_id` (`option_type_id`),
  KEY `index_spree_option_values_on_position` (`position`)
) ENGINE=InnoDB AUTO_INCREMENT=2000000 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;

CREATE TABLE `spree_option_values_variants` (
  `id` int NOT NULL AUTO_INCREMENT,
  `variant_id` int DEFAULT NULL COMMENT 'group 1',
  `option_value_id` int DEFAULT NULL COMMENT 'group 2',
  `created_at` datetime(6) DEFAULT CURRENT_TIMESTAMP,
  `updated_at` datetime(6) DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  KEY `index_option_values_variants_on_variant_id_and_option_value_id` (`variant_id`,`option_value_id`),
  KEY `index_spree_option_values_variants_on_variant_id` (`variant_id`)
) ENGINE=InnoDB AUTO_INCREMENT=4000000 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;

CREATE TABLE `spree_shipments` (
  `id` int NOT NULL AUTO_INCREMENT,
  `tracking` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{3,20}"',
  `number` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{3,20}"',
  `cost` decimal(10,2) DEFAULT '20.11'
  `shipped_at` datetime DEFAULT CURRENT_TIMESTAMP,
  `order_id` int DEFAULT 'group 1',
  `deprecated_address_id` int DEFAULT NULL,
  `state` varchar(255) DEFAULT NULL COMMENT 'REGEX "[A-Z][a-z]{2,2}"',
  `created_at` datetime(6) DEFAULT CURRENT_TIMESTAMP,
  `updated_at` datetime(6) DEFAULT CURRENT_TIMESTAMP,
  `stock_location_id` int DEFAULT NULL,
  `adjustment_total` decimal(10,2) DEFAULT NULL,
  `additional_tax_total` decimal(10,2) DEFAULT NULL,
  `promo_total` decimal(10,2) DEFAULT NULL,
  `included_tax_total` decimal(10,2) NOT NULL,
  PRIMARY KEY (`id`),
  KEY `index_spree_shipments_on_deprecated_address_id` (`deprecated_address_id`),
  KEY `index_shipments_on_number` (`number`),
  KEY `index_spree_shipments_on_order_id` (`order_id`),
  KEY `index_spree_shipments_on_stock_location_id` (`stock_location_id`)
) ENGINE=InnoDB AUTO_INCREMENT=1000000 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
